-
Notifications
You must be signed in to change notification settings - Fork 3
Expand file tree
/
Copy pathfiles.html
More file actions
234 lines (232 loc) · 36.8 KB
/
Copy pathfiles.html
File metadata and controls
234 lines (232 loc) · 36.8 KB
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
<!-- HTML header for doxygen 1.9.1-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<!-- Google tag (gtag.js) -->
<script async src="https://www.googletagmanager.com/gtag/js?id=G-SY496B9L99"></script>
<script>
window.dataLayer = window.dataLayer || [];
function gtag(){dataLayer.push(arguments);}
gtag('js', new Date());
gtag('config', 'G-SY496B9L99');
</script>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" content="Doxygen 1.16.1"/>
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<title>MFC: File List</title>
<meta name="description" content="File List — MFC documentation. Open-source exascale multiphase flow solver." />
<meta name="keywords" content="exascale, fluid dynamics, cfd, computational fluid dynamics, compressible, hpc, bryngelson, colonius, subgrid, multiphase, frontier, summit, el capitan, aurora, amd gpu, gpu, nvidia"/>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="navtree.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="navtreedata.js"></script>
<script type="text/javascript" src="navtree.js"></script>
<script type="text/javascript" src="cookie.js"></script>
<link href="search/search.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="search/searchdata.js"></script>
<script type="text/javascript" src="search/search.js"></script>
<script type="text/x-mathjax-config">
MathJax.Hub.Config({
extensions: ["tex2jax.js", "TeX/AMSmath.js", "TeX/AMSsymbols.js"],
jax: ["input/TeX","output/HTML-CSS"],
});
// This file is set as MATHJAX_CODEFILE in the Doxyfile. It configures how
// MathJax renders expressions in Markdown so that it is consistent with GitHub.
MathJax.Hub.Config({
extensions: ["tex2jax.js"],
jax: ["input/TeX", "output/HTML-CSS"],
tex2jax: {
inlineMath: [ ['$', '$'], ["\\(","\\)"] ],
displayMath: [ ['$$','$$'], ["\\[","\\]"] ],
processEscapes: true,
ignoreClass: "line" // Ignore code blocks: https://web.archive.org/web/20120430100225/http://www.mathjax.org/docs/1.1/options/tex2jax.html
},
"HTML-CSS": {
fonts: ["TeX"]
}
});
</script>
<script type="text/javascript" async="async" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
<link rel="shortcut icon" href="icon.ico" type="image/x-icon" />
<link href="doxygen-awesome.css" rel="stylesheet" type="text/css"/>
<link href="doxygen-awesome-sidebar-only.css" rel="stylesheet" type="text/css"/>
<link href="custom.css" rel="stylesheet" type="text/css"/>
</head>
<body>
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
<tbody>
<tr style="height: 56px;">
<td id="projectlogo"><img alt="Logo" src="icon.ico"/></td>
<td id="projectalign" style="padding-left: 0.5em;">
<div id="projectname">MFC
</div>
<div id="projectbrief">Exascale flow solver</div>
</td>
</tr>
</tbody>
</table>
</div>
<!-- Cross-navigation injected into sidebar via script below -->
<script>
document.addEventListener('DOMContentLoaded', function() {
var nav = document.createElement('div');
nav.id = 'mfc-nav';
var items = [
['../documentation/index.html', 'documentation', 'User Guide'],
['../api/index.html', 'api', 'API Documentation']
];
var path = window.location.pathname;
var apiPaths = ['/api/', '/pre_process/', '/simulation/', '/post_process/'];
for (var i = 0; i < items.length; i++) {
var a = document.createElement('a');
a.href = items[i][0];
a.textContent = items[i][2];
if (items[i][1] === 'api') {
for (var j = 0; j < apiPaths.length; j++) {
if (path.indexOf(apiPaths[j]) !== -1) { a.className = 'active'; break; }
}
} else {
if (path.indexOf('/' + items[i][1] + '/') !== -1) a.className = 'active';
}
nav.appendChild(a);
}
var sideNav = document.getElementById('side-nav');
if (sideNav) sideNav.insertBefore(nav, sideNav.firstChild);
});
</script>
<!-- end header part -->
<!-- Generated by Doxygen 1.16.1 -->
<script type="text/javascript">
var searchBox = new SearchBox("searchBox", "search/",'.html');
</script>
<script type="text/javascript">
$(function() { codefold.init(); });
</script>
<script type="text/javascript" src="menudata.js"></script>
<script type="text/javascript" src="menu.js"></script>
<script type="text/javascript">
$(function() {
initMenu('',true,false,'search.php','Search',true);
$(function() { init_search(); });
});
</script>
<div id="main-nav"></div>
</div><!-- top -->
<div id="side-nav" class="ui-resizable side-nav-resizable">
<div id="nav-tree">
<div id="nav-tree-contents">
<div id="nav-sync" class="sync"></div>
</div>
</div>
<div id="splitbar" style="-moz-user-select:none;"
class="ui-resizable-handle">
</div>
</div>
<script type="text/javascript">
$(function(){initNavTree('files.html','',''); });
</script>
<div id="container">
<div id="doc-content">
<!-- window showing the filter options -->
<div id="MSearchSelectWindow"
onmouseover="return searchBox.OnSearchSelectShow()"
onmouseout="return searchBox.OnSearchSelectHide()"
onkeydown="return searchBox.OnSearchSelectKey(event)">
</div>
<!-- iframe showing the search results (closed by default) -->
<div id="MSearchResultsWindow">
<div id="MSearchResults">
<div class="SRPage">
<div id="SRIndex">
<div id="SRResults"></div>
<div class="SRStatus" id="Loading">Loading...</div>
<div class="SRStatus" id="Searching">Searching...</div>
<div class="SRStatus" id="NoMatches">No Matches</div>
</div>
</div>
</div>
</div>
<div class="header">
<div class="headertitle"><div class="title">File List</div></div>
</div><!--header-->
<div class="contents">
<div class="textblock">Here is a list of all files with brief descriptions:</div><div class="directory">
<table class="directory">
<tr id="row_0_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__acoustic__src_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__acoustic__src_8fpp_8f90.html" target="_self">m_acoustic_src.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__acoustic__src.html" title="One-way acoustic source injection, Maeda and Colonius JCP (2017).">m_acoustic_src</a> </td></tr>
<tr id="row_1_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__body__forces_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__body__forces_8fpp_8f90.html" target="_self">m_body_forces.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__body__forces.html" title="Computes gravitational and body force source terms for the momentum equations.">m_body_forces</a> </td></tr>
<tr id="row_2_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__common_8fpp_8f90.html" target="_self">m_boundary_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__common.html" title="Noncharacteristic and processor boundary condition application for ghost cells and buffer regions.">m_boundary_common</a> </td></tr>
<tr id="row_3_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__io_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__io_8fpp_8f90.html" target="_self">m_boundary_io.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__io.html" title="Boundary condition restart I/O, capillary/IGR buffer population, and grid-variable buffers.">m_boundary_io</a> </td></tr>
<tr id="row_4_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__primitives_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__primitives_8fpp_8f90.html" target="_self">m_boundary_primitives.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__primitives.html" title="Per-cell noncharacteristic boundary condition primitives applied in the ghost cells.">m_boundary_primitives</a> </td></tr>
<tr id="row_5_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__bubbles_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__bubbles_8fpp_8f90.html" target="_self">m_bubbles.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__bubbles.html" title="Bubble-dynamics procedures for ensemble- and volume-averaged model.">m_bubbles</a> </td></tr>
<tr id="row_6_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__bubbles__EE_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__bubbles__EE_8fpp_8f90.html" target="_self">m_bubbles_EE.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__bubbles__ee.html" title="m_bubbles_ee">m_bubbles_EE</a> </td></tr>
<tr id="row_7_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__bubbles__EL_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__bubbles__EL_8fpp_8f90.html" target="_self">m_bubbles_EL.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__bubbles__el.html" title="m_bubbles_el">m_bubbles_EL</a> </td></tr>
<tr id="row_8_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__bubbles__EL__kernels_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__bubbles__EL__kernels_8fpp_8f90.html" target="_self">m_bubbles_EL_kernels.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__bubbles__el__kernels.html" title="m_bubbles_el_kernels">m_bubbles_EL_kernels</a> </td></tr>
<tr id="row_9_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__cbc_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__cbc_8fpp_8f90.html" target="_self">m_cbc.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__cbc.html" title="Characteristic boundary conditions (CBC) for slip walls, non-reflecting subsonic inflow/outflow,...">m_cbc</a> </td></tr>
<tr id="row_10_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__checker_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__checker_8fpp_8f90.html" target="_self">m_checker.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__checker.html" title="Validates simulation input parameters for consistency and supported configurations.">m_checker</a> </td></tr>
<tr id="row_11_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__checker__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__checker__common_8fpp_8f90.html" target="_self">m_checker_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__checker__common.html" title="Shared input validation checks for grid dimensions and AMD GPU compiler limits.">m_checker_common</a> </td></tr>
<tr id="row_12_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__chemistry_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__chemistry_8fpp_8f90.html" target="_self">m_chemistry.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__chemistry.html" title="Multi-species chemistry interface for thermodynamic properties, reaction rates, and transport coeffic...">m_chemistry</a> </td></tr>
<tr id="row_13_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__collisions_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__collisions_8fpp_8f90.html" target="_self">m_collisions.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__collisions.html" title="Ghost-node immersed boundary method: locates ghost/image points, computes interpolation coefficients,...">m_collisions</a> </td></tr>
<tr id="row_14_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__compute__cbc_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__compute__cbc_8fpp_8f90.html" target="_self">m_compute_cbc.fpp.f90</a></td><td class="desc">CBC computation module </td></tr>
<tr id="row_15_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__compute__levelset_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__compute__levelset_8fpp_8f90.html" target="_self">m_compute_levelset.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__compute__levelset.html" title="Computes signed-distance level-set fields and surface normals for immersed-boundary patch geometries.">m_compute_levelset</a> </td></tr>
<tr id="row_16_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__constants_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__constants_8fpp_8f90.html" target="_self">m_constants.fpp.f90</a></td><td class="desc">Contains constant values used throughout the code(s) </td></tr>
<tr id="row_17_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__data__output_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__data__output_8fpp_8f90.html" target="_self">m_data_output.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__data__output.html" title="Writes solution data, run-time stability diagnostics (ICFL, VCFL, CCFL, Rc), and probe/center-of-mass...">m_data_output</a> </td></tr>
<tr id="row_18_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__derived__types_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__derived__types_8fpp_8f90.html" target="_self">m_derived_types.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__derived__types.html" title="Shared derived types for field data, patch geometry, bubble dynamics, and MPI I/O structures.">m_derived_types</a> </td></tr>
<tr id="row_19_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__derived__variables_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__derived__variables_8fpp_8f90.html" target="_self">m_derived_variables.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__derived__variables.html" title="Derives diagnostic flow quantities (vorticity, speed of sound, numerical Schlieren,...">m_derived_variables</a> </td></tr>
<tr id="row_20_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__fftw_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__fftw_8fpp_8f90.html" target="_self">m_fftw.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__fftw.html" title="Forward and inverse FFT wrappers (FFTW/cuFFT/hipFFT) for azimuthal Fourier filtering in cylindrical g...">m_fftw</a> </td></tr>
<tr id="row_21_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__finite__differences_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__finite__differences_8fpp_8f90.html" target="_self">m_finite_differences.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__finite__differences.html" title="Finite difference operators for computing divergence of velocity fields.">m_finite_differences</a> </td></tr>
<tr id="row_22_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__global__parameters_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__global__parameters_8fpp_8f90.html" target="_self">m_global_parameters.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__global__parameters.html" title="Global parameters for the computational domain, fluid properties, and simulation algorithm configurat...">m_global_parameters</a> </td></tr>
<tr id="row_23_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__global__parameters__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__global__parameters__common_8fpp_8f90.html" target="_self">m_global_parameters_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__global__parameters__common.html" title="Shared global parameters and equation-index setup for all three executables. Each per-target m_global...">m_global_parameters_common</a> </td></tr>
<tr id="row_24_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__hb__function_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__hb__function_8fpp_8f90.html" target="_self">m_hb_function.fpp.f90</a></td><td class="desc"></td></tr>
<tr id="row_25_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__helper_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__helper_8fpp_8f90.html" target="_self">m_helper.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__helper.html" title="Utility routines for bubble model setup, coordinate transforms, array sampling, and special functions...">m_helper</a> </td></tr>
<tr id="row_26_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__helper__basic_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__helper__basic_8fpp_8f90.html" target="_self">m_helper_basic.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__helper__basic.html" title="Basic floating-point utilities: approximate equality, default detection, and coordinate bounds.">m_helper_basic</a> </td></tr>
<tr id="row_27_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__hypoelastic_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__hypoelastic_8fpp_8f90.html" target="_self">m_hypoelastic.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__hypoelastic.html" title="Computes hypoelastic stress-rate source terms and damage-state evolution.">m_hypoelastic</a> </td></tr>
<tr id="row_28_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__ib__patches_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__ib__patches_8fpp_8f90.html" target="_self">m_ib_patches.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__ib__patches.html" title="Allocate memory and read initial condition data for IC extrusion.">m_ib_patches</a> </td></tr>
<tr id="row_29_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__ibm_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__ibm_8fpp_8f90.html" target="_self">m_ibm.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__ibm.html" title="Ghost-node immersed boundary method: locates ghost/image points, computes interpolation coefficients,...">m_ibm</a> </td></tr>
<tr id="row_30_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__igr_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__igr_8fpp_8f90.html" target="_self">m_igr.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__igr.html" title="Iterative ghost rasterization (IGR) for sharp immersed boundary treatment.">m_igr</a> </td></tr>
<tr id="row_31_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__model_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__model_8fpp_8f90.html" target="_self">m_model.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__model.html" title="Binary STL file reader and processor for immersed boundary geometry.">m_model</a> </td></tr>
<tr id="row_32_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__mpi__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__mpi__common_8fpp_8f90.html" target="_self">m_mpi_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__mpi__common.html" title="MPI communication layer: domain decomposition, halo exchange, reductions, and parallel I/O setup.">m_mpi_common</a> </td></tr>
<tr id="row_33_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__mpi__proxy_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__mpi__proxy_8fpp_8f90.html" target="_self">m_mpi_proxy.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__mpi__proxy.html" title="MPI halo exchange, domain decomposition, and buffer packing/unpacking for the simulation solver.">m_mpi_proxy</a> </td></tr>
<tr id="row_34_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__muscl_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__muscl_8fpp_8f90.html" target="_self">m_muscl.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__muscl.html" title="MUSCL reconstruction with interface sharpening for contact-preserving advection.">m_muscl</a> </td></tr>
<tr id="row_35_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__particle__cloud_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__particle__cloud_8fpp_8f90.html" target="_self">m_particle_cloud.fpp.f90</a></td><td class="desc"></td></tr>
<tr id="row_36_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__patch__geometries_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__patch__geometries_8fpp_8f90.html" target="_self">m_patch_geometries.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__patch__geometries.html" title="Contains helper functions specific to various patch gemoetries for determining if a grid cell lies in...">m_patch_geometries</a> </td></tr>
<tr id="row_37_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__phase__change_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__phase__change_8fpp_8f90.html" target="_self">m_phase_change.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__phase__change.html" title="Phase transition relaxation solvers for liquid-vapor flows with cavitation and boiling.">m_phase_change</a> </td></tr>
<tr id="row_38_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__pressure__relaxation_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__pressure__relaxation_8fpp_8f90.html" target="_self">m_pressure_relaxation.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__pressure__relaxation.html" title="Pressure relaxation for the six-equation multi-component model via Newton–Raphson equilibration and v...">m_pressure_relaxation</a> </td></tr>
<tr id="row_39_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__qbmm_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__qbmm_8fpp_8f90.html" target="_self">m_qbmm.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__qbmm.html" title="Quadrature-based moment methods (QBMM) for polydisperse bubble moment inversion and transport.">m_qbmm</a> </td></tr>
<tr id="row_40_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__reactive__burn_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__reactive__burn_8fpp_8f90.html" target="_self">m_reactive_burn.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__reactive__burn.html" title="Condensed-phase reactive burn: a pressure-driven programmed-burn source that converts a "reactant" fl...">m_reactive_burn</a> </td></tr>
<tr id="row_41_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__rhs_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__rhs_8fpp_8f90.html" target="_self">m_rhs.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__rhs.html" title="Assemble the right-hand side of the governing equations using finite-volume flux differencing,...">m_rhs</a> </td></tr>
<tr id="row_42_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__riemann__solver__hll_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__riemann__solver__hll_8fpp_8f90.html" target="_self">m_riemann_solver_hll.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__riemann__solver__hll.html" title="HLL approximate Riemann solver, Harten et al. SIAM Review (1983).">m_riemann_solver_hll</a> </td></tr>
<tr id="row_43_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__riemann__solver__hllc_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__riemann__solver__hllc_8fpp_8f90.html" target="_self">m_riemann_solver_hllc.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__riemann__solver__hllc.html" title="HLLC Riemann solver with contact restoration, Toro et al. Shock Waves (1994).">m_riemann_solver_hllc</a> </td></tr>
<tr id="row_44_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__riemann__solver__hlld_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__riemann__solver__hlld_8fpp_8f90.html" target="_self">m_riemann_solver_hlld.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__riemann__solver__hlld.html" title="HLLD approximate Riemann solver for MHD, Miyoshi & Kusano JCP (2005).">m_riemann_solver_hlld</a> </td></tr>
<tr id="row_45_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__riemann__solver__lf_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__riemann__solver__lf_8fpp_8f90.html" target="_self">m_riemann_solver_lf.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__riemann__solver__lf.html" title="Lax-Friedrichs (Rusanov) approximate Riemann solver.">m_riemann_solver_lf</a> </td></tr>
<tr id="row_46_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__riemann__solvers_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__riemann__solvers_8fpp_8f90.html" target="_self">m_riemann_solvers.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__riemann__solvers.html" title="Approximate and exact Riemann solvers (HLL, HLLC, HLLD, exact) for the multicomponent Navier–Stokes e...">m_riemann_solvers</a> </td></tr>
<tr id="row_47_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__riemann__state_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__riemann__state_8fpp_8f90.html" target="_self">m_riemann_state.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__riemann__state.html" title="Shared Riemann-solver module state and the per-sweep setup, state-buffer population,...">m_riemann_state</a> </td></tr>
<tr id="row_48_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__sim__helpers_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__sim__helpers_8fpp_8f90.html" target="_self">m_sim_helpers.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__sim__helpers.html" title="Simulation helper routines for enthalpy computation, CFL calculation, and stability checks.">m_sim_helpers</a> </td></tr>
<tr id="row_49_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__start__up_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__start__up_8fpp_8f90.html" target="_self">m_start_up.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__start__up.html" title="Reads input files, loads initial conditions and grid data, and orchestrates solver initialization and...">m_start_up</a> </td></tr>
<tr id="row_50_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__surface__tension_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__surface__tension_8fpp_8f90.html" target="_self">m_surface_tension.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__surface__tension.html" title="Computes capillary source fluxes and color-function gradients for the diffuse-interface surface tensi...">m_surface_tension</a> </td></tr>
<tr id="row_51_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__thinc_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__thinc_8fpp_8f90.html" target="_self">m_thinc.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__thinc.html" title="THINC and MTHINC interface compression for volume fraction sharpening. THINC (int_comp=1): 1D directi...">m_thinc</a> </td></tr>
<tr id="row_52_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__time__steppers_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__time__steppers_8fpp_8f90.html" target="_self">m_time_steppers.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__time__steppers.html" title="Total-variation-diminishing (TVD) Runge–Kutta time integrators (1st-, 2nd-, and 3rd-order SSP).">m_time_steppers</a> </td></tr>
<tr id="row_53_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__variables__conversion_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__variables__conversion_8fpp_8f90.html" target="_self">m_variables_conversion.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__variables__conversion.html" title="Conservative-to-primitive variable conversion, mixture property evaluation, and pressure computation.">m_variables_conversion</a> </td></tr>
<tr id="row_54_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__viscous_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__viscous_8fpp_8f90.html" target="_self">m_viscous.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__viscous.html" title="Computes viscous stress tensors and diffusive flux contributions for the Navier–Stokes equations.">m_viscous</a> </td></tr>
<tr id="row_55_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__weno_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__weno_8fpp_8f90.html" target="_self">m_weno.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__weno.html" title="WENO/WENO-Z/TENO reconstruction with optional monotonicity-preserving bounds and mapped weights.">m_weno</a> </td></tr>
<tr id="row_56_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="p__main_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="p__main_8fpp_8f90.html" target="_self">p_main.fpp.f90</a></td><td class="desc">Contains program p_main </td></tr>
<tr id="row_57_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__compile__specific_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__compile__specific_8f90.html" target="_self">m_compile_specific.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__compile__specific.html" title="Platform-specific file and directory operations: create, delete, inquire, getcwd, and basename.">m_compile_specific</a> </td></tr>
<tr id="row_58_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__delay__file__access_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__delay__file__access_8f90.html" target="_self">m_delay_file_access.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__delay__file__access.html" title="Rank-staggered file access delays to prevent I/O contention on parallel file systems.">m_delay_file_access</a> </td></tr>
<tr id="row_59_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__nvtx_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__nvtx_8f90.html" target="_self">m_nvtx.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__nvtx.html" title="NVIDIA NVTX profiling API bindings for GPU performance instrumentation.">m_nvtx</a> </td></tr>
<tr id="row_60_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__precision__select_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__precision__select_8f90.html" target="_self">m_precision_select.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__precision__select.html" title="Working-precision kind selection (half/single/double) and corresponding MPI datatype parameters.">m_precision_select</a> </td></tr>
</table>
</div><!-- directory -->
</div><!-- contents -->
</div><!-- doc-content -->
</div><!-- container -->
<!-- HTML footer for doxygen 1.9.1-->
<!-- start footer part -->
<div id="nav-path" class="navpath">
<ul></ul>
</div>
</body>
</html>